# CHANGELOG



## v1.0.1 (2024-06-25)

### Fix

* fix: update README ([`a4d35f9`](https://github.com/NaturalAntibody/riot_na/commit/a4d35f9254c1f5edc911cd4489de326cfda5305b))


## v1.0.0 (2024-06-25)

### Breaking

* feat!: init commit ([`8228cf2`](https://github.com/NaturalAntibody/riot_na/commit/8228cf2144a8a348c35c437121954c4797569f2d))

### Unknown

* bump: 1.0.0 [skip ci]

Automatically generated by python-semantic-release ([`2db4fdc`](https://github.com/NaturalAntibody/riot_na/commit/2db4fdc3545e8e1a940f04deda11ad2a7f2926e7))
